# Compare VariantModel instance pk: 1

Compare Jan. 1, 2010, 1 a.m. with Jan. 1, 2010, 1 a.m. :

‹ Go back to history list | Revert to this version ›

### boolean

False changed to: True

### null boolean

None changed to: False

### char

    - a
    + B

### choices char

    - alpha
    + bravo

### text

    - Foo 'one'
    + Bar 'two'

### integer

    - 0
    + -1

### integers

    - 1,2,3
    + 2,3,4

### positive integer

    - 1
    + 3

### big integer

    - -9223372036854775808
    ? -                  ^

    + 9223372036854775807
    ?                   ^

### time

    - 20:15:00
    + 19:30:00

### date

    - 1941-05-12
    + 2099-12-31

### datetime

    - Aug. 19, 2005, 8:13 a.m. (time since that date: 18 years, 5 months)
    + Jan. 1, 2000, midnight (time since that date: 24 years, 1 month)

### decimal

    - 1.23456789
    + 3.1415926535

### float

    - 2.345
    + 3.1415

### email

    - one@foo-bar.com
    ?  --

    + two@foo-bar.com
    ? ++

### url

    https://www.pylucid.orggithub.com/jedie/

### file field

    /media/file_field_19.txt

### filepath

    - foo/
    + bar/

### ip address

    - 192.168.0.1
    + 10.0.0.0

### json field

    {
        'foo': {
            'bar': {
                'baz': [
                    123,
                    456'XXX',
                    789
                ]
            }
        }
    }

#### Edit comment:

> 19 change: 'json_field' field.

‹ Go back to history list | Revert to this version ›